*********************************************************************************
*Distribucin del Fondo de Aportaciones para la Infraestructura Social Municipal*
*Ejercicio Fiscal 2013                                                          *
*********************************************************************************
#delimit;
clear;
set mem 500m;
set more off;
cap log close;

gl personas = "C:\Microdatoscenso_2010\Poblacion";
gl viviendas = "C:\Microdatoscenso_2010\Vivienda";
gl temp = "C:\Microdatoscenso_2010\TempFAIS";

log using "$temp\DistFISM2013.scml", replace;

*Indicadores de personas;

use "$personas\personas_18.dta", clear;
gen foliov=ent+mun+id_viv;
destring clavivp edad alfabet escoacum, replace;
drop if clavivp>=5 & clavivp<=7;

recode edad (999=.);

*Nivel educativo promedio del hogar;
*Analfabetismo;
rename alfabet analf;
replace analf=0 if analf==3;
replace analf=. if analf==9;

*Nivel educativo de la persona;
recode escoacum (99=.);
gen norma=.;
replace norma=escoacum/1 if edad==7 | edad==8;
replace norma=escoacum/1 if edad==9;
replace norma=escoacum/2 if edad==10;
replace norma=escoacum/3 if edad==11;
replace norma=escoacum/4 if edad==12;
replace norma=escoacum/5 if edad==13;
replace norma=escoacum/6 if edad>=14 & edad!=.;

gen nei=.;
replace nei=norma if edad>=7 & edad<=9;
replace nei=norma*analf if edad>=10 & edad!=.;

*Brecha educativa;
gen b_educativa=.;
replace b_educativa=1-nei if (edad>=7 & edad!=.) & nei!=. ;

*Ajuste de la brecha educativa;
replace b_educativa=b_educativa/(7.334) if b_educativa<0;

collapse (mean) b_educativa, by(foliov);
sort foliov;
save "$temp\b_educativa2013_18.dta", replace;

*Indicadores de ingreso y vivienda;

use "$viviendas\viviendas_18.dta", clear;
gen foliov=ent+mun+id_viv;
destring clavivp numpers ingtrhog, replace;
drop if clavivp>=5 & clavivp<=7;

*Ingresos por persona;
*Ingreso promedio del hogar. Se acutalizan los ingresos con el INPC INEGI a junio de 2012. Base Junio de 2010;
recode ingtrhog (999999=.);
gen ingreso11=ingtrhog*1.077537;
gen ingpc=ingreso11/numpers;

*Lnea de pobreza alimentaria rural CONEVAL Junio 2012;
scalar lp=877.98;

gen b_ingreso=(lp-ingpc)/lp;

*Reescalamiento del ingreso;

replace b_ingreso=b_ingreso/18 if b_ingreso>=-9 & b_ingreso<0;
replace b_ingreso=-0.5 if b_ingreso<-9;

*Disponibilidad de espacio de la vivienda;
destring cuadorm, replace;
recode cuadorm (99=.);

gen dej=(cuadorm*3)/numpers;

*Reescalamiento de la disponibilidad de espacio de la vivienda;
replace dej=dej*(1.5/75) + (1-(dej/75)) if (dej>1 & dej!=.);

*Brecha de espacio de la vivienda;
gen b_espacio=1-dej if dej!=.;


*Disponibilidad de drenaje;
destring drenaje, replace;
gen d1=.;
replace d1=1.5 if drenaje==1;
replace d1=1.0 if drenaje==2;
replace d1=0.5 if drenaje==3;
replace d1=0.3 if drenaje==4;
replace d1=0.0 if drenaje==5;

*Brecha por disponibilidad de drenaje;
gen b_drenaje=1-d1;


*Disponibilidad de electricidad;
destring electri combus, replace;
recode electri (3=0) (9=.);

gen c=.;
replace c=1.0 if elec==1;
replace c=1.0 if (combust==1 | combust==2) & elec==0;
replace c=0.1 if (combust==3 | combust==4) & elec==0;

*Brecha de electricidad o combustible;
gen b_electricidad=1-c if c!=.;

*Se seleccionan las variables de inters;
keep b_* ingreso11 ingpc foliov factor ent nom_ent numpers nom_mun mun;

*A las bases de vivienda por estado se les incluye la informacin de indicadores de personas;

sort foliov;
merge foliov using "$temp\b_educativa2013_18.dta";
drop _merge;

*ndice global de pobreza de un hogar;
gen igp=(b_ingreso*0.4616) + (b_educativa*0.1250) +  (b_espacio*0.2386) + 
		(b_drenaje*0.0608) + (b_electricidad*0.1140);

*Poblacin en situacin de pobreza extrema;
gen p_ext=1 if igp>=0 & igp<=1;

*Masa carencial del hogar;
gen mch=.;
replace mch=(igp^2)*numpers if p_ext==1;

qui sum mch [w=factor];

*Masa carencial de la entidad;
gen mce=r(sum);

*masa carencial de los municipios;
gen mchf= factor*mch;

egen mchm= sum(mchf), by (mun);

*Participacin de las masas carenciales municipales en la estatal;
gen pme=mchm/mce;
destring ent mun, replace;
tabstat mun mchm pme, stat(mean) by(nom_mun)nototal labelwidth(32);

*Bases a nivel estatal;
save "$temp\estatal2013_18.dta", replace;

log close;




